function [ScanLine] = GetLaserScanPolygon(Pos,Heading,WorldMap,LRF)
    % function [ScanLine] = GetLaserScan(Pos,Heading,WorldMap,LRF)
    % where Pos: [x y] position of the robot
    %       Heading: heading of the robot, in degrees. 0 degree is x-axis
    %       WorldMap : polygon representing the world.
    %       LRF : structure containing LRF parameters. 
    % returns:
    %       ScanLine : a matrix containing the angles (deg) and distance.
    %                  if distance < 0, then there was no object detected.
    %
    % (c) Philippe Giguere 2010
    %     philippe.giguere@ift.ulaval.ca
    %
    xRobot = Pos(1);
    yRobot = Pos(2);
    Draw = false;
    DataIndex = 1;
    for ScanAngle = LRF.StartAngle:LRF.dAngle:LRF.EndAngle
        UsedScanAngle = ScanAngle + Heading;
        xTip = xRobot+LRF.LaserRange*cosd(UsedScanAngle);
        yTip = yRobot+LRF.LaserRange*sind(UsedScanAngle);
        if (LRF.Draw)
            hold on;
            h = line([xRobot xTip],[yRobot yTip]);
            set(h,'Color','r');
        end
        % Use the curveintersect method
        [XCol YCol] = curveintersect([xRobot xTip],[yRobot yTip],WorldMap(1,:),WorldMap(2,:));
        if (~isempty(XCol))
            % Find the location closest to the robot.
            DistanceHit = sqrt((XCol-xRobot).^2+(YCol-yRobot).^2);
            [Distance IndexMin] = min(DistanceHit);
            HitLocation = [XCol(IndexMin) YCol(IndexMin)];
            Hit = true;
        else
            Hit = false;
            HitLocation = [xTip yTip];
        end
        if (LRF.Draw)
            plot(HitLocation(1),HitLocation(2),'*');
            hold off;
        end
        ScanLine(1,DataIndex) = ScanAngle;
        if (Hit)
            ScanLine(2,DataIndex) = max(Distance  + randn*LRF.noise,0);
        else
            ScanLine(2,DataIndex) = LRF.LaserRange;
        end
        DataIndex = DataIndex + 1;
    end
end
